@@ -97,22 +97,11 @@ class SAC(Algo):
 
     Examples
     --------
-    >>> ac = ActorCritic(...)
-    >>> create_algo = SAC.algo_factory(
+    >>> create_algo = SAC.create_factory(
             lr_q=1e-4, lr_pi=1e-4, lr_alpha=1e-4, gamma=0.99, polyak=0.995,
             num_updates=50, update_every=50, test_every=5000, start_steps=20000,
             mini_batch_size=64, alpha=1.0, reward_scaling=1.0, num_test_episodes=0,
              target_update_interval=1)
-    >>> sac1 = create_algo(actor_critic=ac, device=torch.device("cuda:1"))
-    >>> sac2 = create_algo(actor_critic=ac, device=torch.device("cuda:2"))
-
-    >>> ac = ActorCritic(...)
-    >>> sac = SAC(device=torch.device("cuda:1"), actor_critic=ac, lr_q=1e-4,
-                  lr_pi=1e-4, lr_alpha=1e-4 gamma=0.99, polyak=0.995,
-                  num_updates=50, update_every=50, test_every=5000,
-                  start_steps=20000, mini_batch_size=64, alpha=1.0,
-                  reward_scaling=1.0, num_test_episodes=0,
-                  target_update_interval=1)
     """
 
     def __init__(self,
