@@ -14,8 +14,8 @@ class Learner:
 
     Parameters
     ----------
-    update_workers : Worker or WorkerSet
-        The set of workers handling actor_critic updates.
+    scheme : Scheme
+        Training scheme class instance, handling coordination of workers.
     target_steps : int
         Number of environment steps to reach to complete training.
     log_dir : str
@@ -39,12 +39,12 @@ class Learner:
         Training start time.
     """
 
-    def __init__(self, workers, target_steps, log_dir=None):
+    def __init__(self, scheme, target_steps, log_dir=None):
 
         # Input attributes
         self.log_dir = log_dir
         self.target_steps = target_steps
-        self.update_worker = workers.update_worker()
+        self.update_worker = scheme.update_worker()
 
         # Counters and metrics
         self.num_samples_collected = 0
@@ -101,7 +101,7 @@ class Learner:
     def print_info(self):
         """Print relevant information about the training process"""
         s = "Update {}, num samples collected {}, FPS {}".format(
-            self.update_worker.num_updates, self.num_samples_collected,
+            self.update_worker.actor_version, self.num_samples_collected,
             int(self.num_samples_collected / (time.time() - self.start)))
         s += "\n"
         for k, v in self.get_metrics().items():
